@@ -45,8 +45,8 @@ class GroupTests(utils.TestCase, utils.CrudTests):
                          status=200, entity=ref_list)
 
         returned_list = self.manager.list(user=user_id)
-        self.assertTrue(len(returned_list))
-        [self.assertTrue(isinstance(r, self.model)) for r in returned_list]
+        self.assertEqual(len(ref_list), len(returned_list))
+        [self.assertIsInstance(r, self.model) for r in returned_list]
 
     @httpretty.activate
     def test_list_groups_for_domain(self):
@@ -58,8 +58,8 @@ class GroupTests(utils.TestCase, utils.CrudTests):
                          status=200, entity=ref_list)
 
         returned_list = self.manager.list(domain=domain_id)
-        self.assertTrue(len(returned_list))
-        [self.assertTrue(isinstance(r, self.model)) for r in returned_list]
+        self.assertTrue(len(ref_list), len(returned_list))
+        [self.assertIsInstance(r, self.model) for r in returned_list]
 
         self.assertEqual(httpretty.last_request().querystring,
                          {'domain_id': [domain_id]})
